#!/bin/sh -e

# called by uscan with '--upstream-version' <version> <file>

DIR=nailgun-$2
TAG=$(echo "Root_NailGun_$2" | sed "s/\./_/g")

svn export https://nailgun.svn.sourceforge.net/svnroot/nailgun/tags/$TAG/nailgun $DIR

tar cfz nailgun_$2.orig.tar.gz -X debian/orig-tar.exclude $DIR

rm -rf $DIR ../Root_NailGun_*
